@@ -1,12 +1,13 @@
 import inspect
 import time
+import unittest
 
 from iwf.client import Client
 from iwf.command_request import CommandRequest, InternalChannelCommand
 from iwf.command_results import CommandResults, InternalChannelCommandResult
 from iwf.communication import Communication
 from iwf.communication_schema import CommunicationMethod, CommunicationSchema
-from iwf.iwf_api.iwf_api.models import ChannelRequestStatus
+from iwf.iwf_api.models import ChannelRequestStatus
 from iwf.persistence import Persistence
 from iwf.state_decision import StateDecision
 from iwf.state_schema import StateSchema
@@ -21,6 +22,8 @@ test_channel_name2 = "test-internal-channel-2"
 test_channel_name3 = "test-internal-channel-3"
 test_channel_name4 = "test-internal-channel-4"
 
+test_channel_name_prefix = "test-internal-channel-prefix-"
+
 
 class InitState(WorkflowState[None]):
     def execute(
@@ -46,6 +49,9 @@ class WaitAnyWithPublishState(WorkflowState[None]):
     ) -> CommandRequest:
         communication.publish_to_internal_channel(test_channel_name3, 123)
         communication.publish_to_internal_channel(test_channel_name4, "str-value")
+        communication.publish_to_internal_channel(
+            test_channel_name_prefix + "abc", "str-value-for-prefix"
+        )
         return CommandRequest.for_any_command_completed(
             InternalChannelCommand.by_name(test_channel_name1),
             InternalChannelCommand.by_name(test_channel_name2),
@@ -90,6 +96,7 @@ class WaitAllThenPublishState(WorkflowState[None]):
         return CommandRequest.for_all_command_completed(
             InternalChannelCommand.by_name(test_channel_name3),
             InternalChannelCommand.by_name(test_channel_name4),
+            InternalChannelCommand.by_name(test_channel_name_prefix + "abc"),
         )
 
     def execute(
@@ -113,9 +120,12 @@ class InternalChannelWorkflow(ObjectWorkflow):
     def get_communication_schema(self) -> CommunicationSchema:
         return CommunicationSchema.create(
             CommunicationMethod.internal_channel_def(test_channel_name1, int),
-            CommunicationMethod.internal_channel_def(test_channel_name2, type(None)),
+            CommunicationMethod.internal_channel_def(test_channel_name2, None),
             CommunicationMethod.internal_channel_def(test_channel_name3, int),
             CommunicationMethod.internal_channel_def(test_channel_name4, str),
+            CommunicationMethod.internal_channel_def_by_prefix(
+                test_channel_name_prefix, str
+            ),
         )
 
 
@@ -124,8 +134,9 @@ registry.add_workflow(wf)
 client = Client(registry)
 
 
-def test_internal_channel_workflow():
-    wf_id = f"{inspect.currentframe().f_code.co_name}-{time.time_ns()}"
+class TestConditionalComplete(unittest.TestCase):
+    def test_internal_channel_workflow(self):
+        wf_id = f"{inspect.currentframe().f_code.co_name}-{time.time_ns()}"
 
-    client.start_workflow(InternalChannelWorkflow, wf_id, 100, None)
-    client.get_simple_workflow_result_with_wait(wf_id, None)
+        client.start_workflow(InternalChannelWorkflow, wf_id, 100, None)
+        client.get_simple_workflow_result_with_wait(wf_id, None)
